#ifdef ESP32
#include <WiFi.h>
#include <HTTPClient.h>
#else
#include <ESP8266WiFi.h>
#include <ESP8266HTTPClient.h>
#include <WiFiClient.h>
#endif

#include <Wire.h>


const char* ssid     = "Jmeno";
const char* password = "Heslo";

const char* serverName = "IP/update-data.php";

String apiKeyValue = "tPmAT5Ab3j7F9";


const int trigPin = 2;
const int echoPin = 5;

const int Red = 12;
const int Green = 13;


String sensorName = "HC-S04";
String sensorLocation = "P1";
String ipadress = "";
String mac = "";

long duration;
int distance;
String availability;

void setup() {
  pinMode(trigPin, OUTPUT); 
  pinMode(echoPin, INPUT); 
  Serial.begin(115200);

  WiFi.begin(ssid, password);
  Serial.println("Připojuje se...");
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
  }
  Serial.println("");
  Serial.print("Připojeno k WiFi pod IP Adresou: ");
  Serial.println(WiFi.localIP());
  Serial.println("");
  Serial.print("MAC: ");
  Serial.println(WiFi.macAddress());

  ipadress = WiFi.localIP().toString().c_str();
  mac = WiFi.macAddress();
  
  Serial.println("Nastavení dokončeno");
}


void loop() {
  readData();
  delay(500);
  uploadData();
  delay(2000);
  pingNotifier();
}

void pingNotifier(){
    HTTPClient http;
    http.begin("http://192.168.1.18:3000/update-clients");
    http.GET();
    String payload = http.getString();
    Serial.println(payload);
    http.end();
  }

void readData() {
  digitalWrite(trigPin, LOW);  // uvolni piny
  delayMicroseconds(2);
  digitalWrite(trigPin, HIGH);// na 10 microsekund nastaví HIGH
  delayMicroseconds(10);
  digitalWrite(trigPin, LOW);
  duration = pulseIn(echoPin, HIGH);// čtě echoPin, vrací cask v mikrosekundách (jak dlouho)
  distance = duration * 0.034 / 2;  // vypocet vzdalenosti podle rychlosti zvuku
  Serial.print("Distance: ");
  Serial.println(distance);
  if(distance>50){
    availability="true";
    led("Green");
    }else{
    availability="false";
    led("Red");
      }
  delay(1000);
}

void led(String led){
  switch (led) {
  case "Green":
    digitalWrite(Red, LOW);
    delay(100);
    digitalWrite(Green, HIGH);
    break;
  case "Red":
    digitalWrite(Green, LOW);
    delay(100);
    digitalWrite(Red, HIGH);
    break;
  default:
    Serial.println("Chyba");
    break;
}
  }

void uploadData() { 
  if (WiFi.status() == WL_CONNECTED) {  //zkontroluje WiFi připojení
    HTTPClient http;

    http.begin(serverName); //vytvoří spojení s Raspberry Pi serverem

    http.addHeader("Content-Type", "application/x-www-form-urlencoded"); // nastavení headeru

  // příprava HTTP POST 
    String httpRequestData = "api_key=" + apiKeyValue + 
                             "&sensor=" + sensorName  +
                             "&location=" + sensorLocation + 
                             "&availability=" + availability + 
                             "&realValue=" + distance + 
                             "&ipAdress=" + ipadress + 
                             "&senzorID=" + mac + 
                             "";
    Serial.print("httpRequestData: ");
    Serial.println(httpRequestData);
 
    int httpResponseCode = http.POST(httpRequestData); // pošle HTTP POST request

    if (httpResponseCode > 0) {
      Serial.print("HTTP Response code: ");
      Serial.println(httpResponseCode);
      String payload = http.getString();
      Serial.println(payload);
    }
    else {
      Serial.print("Error code: ");
      Serial.println(httpResponseCode);
    }
   
    http.end();
  }
  else {
    Serial.println("WiFi Disconnected");
  }

}
